==> kubernetes-model-core-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/GCEPersistentDiskVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface GCEPersistentDiskVolumeSourceFluent<A extends GCEPersistentDiskVolumeSourceFluent<A>> extends Fluent<A> {


    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public A withNewFsType(StringBuilder arg1);
    public A withNewFsType(int[] arg1,int arg2,int arg3);
    public A withNewFsType(char[] arg1);
    public A withNewFsType(StringBuffer arg1);
    public A withNewFsType(byte[] arg1,int arg2);
    public A withNewFsType(byte[] arg1);
    public A withNewFsType(char[] arg1,int arg2,int arg3);
    public A withNewFsType(byte[] arg1,int arg2,int arg3);
    public A withNewFsType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewFsType(String arg1);
    public Integer getPartition();
    public A withPartition(Integer partition);
    public Boolean hasPartition();
    public A withNewPartition(int arg1);
    public String getPdName();
    public A withPdName(String pdName);
    public Boolean hasPdName();
    public A withNewPdName(StringBuilder arg1);
    public A withNewPdName(int[] arg1,int arg2,int arg3);
    public A withNewPdName(char[] arg1);
    public A withNewPdName(StringBuffer arg1);
    public A withNewPdName(byte[] arg1,int arg2);
    public A withNewPdName(byte[] arg1);
    public A withNewPdName(char[] arg1,int arg2,int arg3);
    public A withNewPdName(byte[] arg1,int arg2,int arg3);
    public A withNewPdName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewPdName(String arg1);
    public Boolean getReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
}

==> kubernetes-model-core-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/GCEPersistentDiskVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Integer;
import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface GCEPersistentDiskVolumeSourceFluent<A extends GCEPersistentDiskVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public A withNewFsType(StringBuilder arg1);
    public A withNewFsType(int[] arg1,int arg2,int arg3);
    public A withNewFsType(char[] arg1);
    public A withNewFsType(StringBuffer arg1);
    public A withNewFsType(byte[] arg1,int arg2);
    public A withNewFsType(byte[] arg1);
    public A withNewFsType(char[] arg1,int arg2,int arg3);
    public A withNewFsType(byte[] arg1,int arg2,int arg3);
    public A withNewFsType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewFsType(String arg1);
    public Integer getPartition();
    public A withPartition(Integer partition);
    public Boolean hasPartition();
    public A withNewPartition(int arg0);
    public String getPdName();
    public A withPdName(String pdName);
    public Boolean hasPdName();
    public A withNewPdName(StringBuilder arg1);
    public A withNewPdName(int[] arg1,int arg2,int arg3);
    public A withNewPdName(char[] arg1);
    public A withNewPdName(StringBuffer arg1);
    public A withNewPdName(byte[] arg1,int arg2);
    public A withNewPdName(byte[] arg1);
    public A withNewPdName(char[] arg1,int arg2,int arg3);
    public A withNewPdName(byte[] arg1,int arg2,int arg3);
    public A withNewPdName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewPdName(String arg1);
    public Boolean getReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
}
